@@ -49,8 +49,9 @@ main(int  argc,				/* I - Number of command-line args */
      char *argv[])			/* I - Command-line arguments */
 {
   const char	*device_uri;            /* URI with which we were called */
-  char queue_name[1024];
-  const char *ptr1;
+  char scheme[32], username[10], queue_name[1024], resource[10];
+  int port, status;
+  const char *ptr1 = NULL;
   char *ptr2;
   const char *job_id;
   int i;
@@ -97,13 +98,18 @@ main(int  argc,				/* I - Number of command-line args */
 
       device_uri = argv[0];
     }
-    if ((ptr1 = strchr(device_uri, ':')) == NULL) {
+    status = httpSeparateURI(HTTP_URI_CODING_ALL, device_uri,
+			     scheme, sizeof(scheme),
+			     username, sizeof(username),
+			     queue_name, sizeof(queue_name),
+			     &port,
+			     resource, sizeof(resource));
+    if (status != HTTP_URI_STATUS_OK &&
+	status != HTTP_URI_STATUS_UNKNOWN_SCHEME) {
       fprintf(stderr, "ERROR: Incorrect device URI syntax: %s\n",
 	      device_uri);
       return (CUPS_BACKEND_STOP);
     }
-    ptr1 ++;
-    strncpy(queue_name, ptr1, sizeof(queue_name));
     httpAssembleURIf(HTTP_URI_CODING_ALL, uri, sizeof(uri), "ipp", NULL,
 		     "localhost", ippPort(), "/printers/%s", queue_name);
     job_id = argv[1];
@@ -201,8 +207,18 @@ main(int  argc,				/* I - Number of command-line args */
       int fd, job_id;
       char buffer[8192];
 
+      ptr2 = strrchr(dest_host, '/');
+      if (ptr2) {
+	*ptr2 = '\0';
+	ptr2 ++;
+      } else
+	ptr2 = queue_name;
+      
       fprintf(stderr, "DEBUG: Received destination host name from cups-browsed: %s\n",
 	      dest_host);
+      fprintf(stderr, "DEBUG: Received destination queue name from cups-browsed: %s\n",
+	      ptr2);
+
       /* Instead of feeding the job into the IPP backend, we re-print it into
 	 the server's CUPS queue. This way the job gets spooled on the server
 	 and we are not blocked until the job is printed. So a subsequent job
@@ -232,7 +248,7 @@ main(int  argc,				/* I - Number of command-line args */
 	fd = 0; /* stdin */
       
       /* Queue the job directly on the server */
-      if ((job_id = cupsCreateJob(CUPS_HTTP_DEFAULT, queue_name,
+      if ((job_id = cupsCreateJob(CUPS_HTTP_DEFAULT, ptr2,
 				  title ? title : "(stdin)",
 				  num_options, options)) > 0) {
 	http_status_t       status;         /* Write status */
@@ -245,7 +261,7 @@ main(int  argc,				/* I - Number of command-line args */
 					 options)) == NULL)
 	  format = CUPS_FORMAT_AUTO;
 	
-	status = cupsStartDocument(CUPS_HTTP_DEFAULT, queue_name, job_id, NULL,
+	status = cupsStartDocument(CUPS_HTTP_DEFAULT, ptr2, job_id, NULL,
 				   format, 1);
 
 	while (status == HTTP_CONTINUE &&
@@ -255,15 +271,15 @@ main(int  argc,				/* I - Number of command-line args */
 	if (status != HTTP_CONTINUE) {
 	  fprintf(stderr, "ERROR: %s: Unable to queue the print data - %s. Retrying.",
 		  argv[0], httpStatus(status));
-	  cupsFinishDocument(CUPS_HTTP_DEFAULT, queue_name);
-	  cupsCancelJob2(CUPS_HTTP_DEFAULT, queue_name, job_id, 0);
+	  cupsFinishDocument(CUPS_HTTP_DEFAULT, ptr2);
+	  cupsCancelJob2(CUPS_HTTP_DEFAULT, ptr2, job_id, 0);
 	  return (CUPS_BACKEND_RETRY);
 	}
 
-	if (cupsFinishDocument(CUPS_HTTP_DEFAULT, queue_name) != IPP_OK) {
+	if (cupsFinishDocument(CUPS_HTTP_DEFAULT, ptr2) != IPP_OK) {
 	  fprintf(stderr, "ERROR: %s: Unable to complete the job - %s. Retrying.",
 		  argv[0], cupsLastErrorString());
-	  cupsCancelJob2(CUPS_HTTP_DEFAULT, queue_name, job_id, 0);
+	  cupsCancelJob2(CUPS_HTTP_DEFAULT, ptr2, job_id, 0);
 	  return (CUPS_BACKEND_RETRY);
 	}
       }
